<?php
/**
 * @package     Joomla.Libraries
 * @subpackage  Toolbar
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('JPATH_PLATFORM') or die;

/**
 * Renders a custom button
 *
 * @package     Joomla.Libraries
 * @subpackage  Toolbar
 * @since       3.0
 */
function crbc_languages_removeParam($url, $param) {
    $url = preg_replace('/(&|\?)'.preg_quote($param).'=[^&]*$/', '', $url);
    $url = preg_replace('/(&|\?)'.preg_quote($param).'=[^&]*&/', '$1', $url);
    return $url;
}

class JToolbarButtonCrbclanguages extends JToolbarButton
{
	/**
	 * Button type
	 *
	 * @var    string
	 */
	protected $_name = 'Crbclanguages';

	/**
	 * Fetch the HTML for the button
	 *
	 * @param   string  $type  Button type, unused string.
	 * @param   string  $html  HTML strng for the button
	 * @param   string  $id    CSS id for the button
	 *
	 * @return  string   HTML string for the button
	 *
	 * @since   3.0
	 */
	public function fetchButton($type = 'Crbclanguages', $html = '', $id = 'crbclanguages')
	{
                
            if(JFactory::getApplication()->input->get('crbc_selected_backend_language', '') != ''){
                // storing the currently selected language code
                JFactory::getSession()->set('com_breezingcommerce.selected_backend_language', JFactory::getApplication()->input->get('crbc_selected_backend_language', ''));
                // reload after selection as this button will be executed after rendering the component
                $url = JUri::getInstance()->toString();
                $url = crbc_languages_removeParam($url,'crbc_selected_backend_language');
                JFactory::getDocument()->addScriptDeclaration("\n".'
                    location.href = "'.$url.'";
                '."\n");
            }
            
            if(JFactory::getApplication()->input->get('crbc_selected_backend_language', '') == 'default'){
                // if there is a wildcard case, then clear everything
                JFactory::getSession()->clear('com_breezingcommerce.selected_backend_language'); 
                JFactory::getSession()->clear('com_breezingcommerce.selected_backend_language_title');
            }
            
            $options = '';
            
            if(count(JLanguageHelper::getLanguages()) > 1){
                
                $languages = JLanguageHelper::getLanguages();
                
                foreach($languages As $language){
                    $asterisk = '';
                    
                    // mark the default one
                    $default = JComponentHelper::getParams('com_languages')->get('administrator');
                    if($language->lang_code != $default){
                        
                        // store the title of the currently selected language
                        if($language->lang_code == JFactory::getSession()->get('com_breezingcommerce.selected_backend_language')){
                            JFactory::getSession()->set('com_breezingcommerce.selected_backend_language_title', $language->title); 
                        }

                        $options .= '<option value="'.htmlentities($language->lang_code, ENT_QUOTES, 'UTF-8').'"'.($language->lang_code == JFactory::getSession()->get('com_breezingcommerce.selected_backend_language') ? ' selected="selected"':'').'>'.htmlentities($language->title, ENT_QUOTES, 'UTF-8').$asterisk.'</option>'."\n";
                    
                    }
                }
                
            } else { 
                
                JFactory::getSession()->clear('com_breezingcommerce.selected_backend_language'); 
                JFactory::getSession()->clear('com_breezingcommerce.selected_backend_language_title'); 
                
                return '';
            }
            
            $url = JUri::getInstance()->toString();
            $url = crbc_languages_removeParam($url,'crbc_selected_backend_language');
            
            $url = $url.(strstr($url,'?') !== false ? '&' : '?');
                    
            JFactory::getDocument()->addStyleDeclaration('.crbc-languages-margin{ margin-right: 10px; position: relative; top: 4px;}');
            JFactory::getDocument()->addScriptDeclaration('
                function crbc_switch_backend_language(select){
                    if(select.selectedIndex > -1){
                        location.href = "'.$url.'crbc_selected_backend_language="+select.options[select.selectedIndex].value;
                    }
                }
            ');
            
            return '<div class="crbc-languages-margin"><select style="outline: none;" onchange="crbc_switch_backend_language(this);"><option value="default">'.JText::_('COM_BREEZINGCOMMERCE_DEFAULT_LANGUAGE').'</option>'.$options.'</select></div>';
	}

	/**
	 * Get the button CSS Id
	 *
	 * @param   string  $type  Not used.
	 * @param   string  $html  Not used.
	 * @param   string  $id    The id prefix for the button.
	 *
	 * @return  string  Button CSS Id
	 *
	 * @since   3.0
	 */
	public function fetchId($type = 'Crbclanguages', $html = '', $id = 'crbclanguages')
	{
		return $this->_parent->getName() . '-' . $id;
	}
}
