<?php
/**
 * @package     BreezingCommerce
 * @author      Markus Bopp
 * @link        http://www.crosstec.de
 * @license     GNU/GPL
*/

// No direct access
defined('_JEXEC') or die('Restricted access');

$libpath = JPATH_ADMINISTRATOR . DS . 'components' . DS . 'com_breezingcommerce' . DS . 'classes' . DS . 'plugin' . DS;
require_once($libpath . 'CrBcProductpricePlugin.php');

interface CrBcProductpriceAdminPlugin extends CrBcProductpricePlugin{
    /**
     * The returned string will be rendered in the product's details and/or combination view.
     * Usually form element items should go here to edit plugin specific settings.
     *
     * The form element names should be prefixed so they won't collide with default parameters from within the product screen.
     *
     * The combination_id will be 0 (zero) if the viewport rendering is happening in product details. 1 (one) if the context will
     * be from within the selected combination.
     *
     * You may use the given $combination_id if your plugin requires to run in combination context as well.
     * If you don't need it, then simply don't use it.
     *
     * If there is nothing to display, return an emptry string.
     *
     * See viewportReceive() on how to handle the transmitted data from the productViewport().
     *
     * @param int $product_id
     * @param int $combination_id
     * @return string
     */
    public function productViewport($product_id, $combination_id);
    /**
     * Should return a double with the raw price.
     * Raw means, no taxes and no rounding included. Just the plain old price as double.
     *
     * Will be called within the CrBcCart class to override the default price.
     *
     * @param int $product_id
     * @param int $combination_id
     * @param int $amount
     * @param double $previous_price
     * @return double
     */
    public static function getPrice($product_id, $combination_id, $amount, $previous_price);
    /**
     * Implement this to receive data from the product details view in administration backend.
     * Use the data to update your settings in for instance database tables.
     *
     * $data will contain request data from wether the product details administration view or the corresponding
     * combination (if productViewport() is not returning an empty string).
     *
     * You may use the given $combination_id if your plugin requires to run in combination context as well.
     * If you don't need it, then simply don't use it.
     *
     * @param int $product_id
     * @param int $combination_id
     * @param array $data
     */
    public static function viewportReceive($product_id, $combination_id, $data);
    /**
     * Gives you the chance to copy the data for the product_id/combination_id
     * when a product copy is triggered.
     *
     * Leave an empty implementation if you don't want to use it.
     *
     * @param int $product_id
     * @param int $combination_id
     */
    public static function copy($product_id, $combination_id);
}